@@ -1,9 +1,9 @@
-"""AsyncDB Meta information."""
+"""DataModel Meta information."""
 
 __title__ = 'python-datamodel'
 __description__ = ('simple library based on python +3.8 to use Dataclass-syntax'
                    'for interacting with Data')
-__version__ = '0.2.5'
+__version__ = '0.6.17'
 __author__ = 'Jesus Lara'
 __author_email__ = 'jesuslarag@gmail.com'
 __license__ = 'BSD'
